const { app, BrowserWindow,contextBridge } = require('electron');
const path = require('path');
const os = require('os');
const fs = require('fs');
const execSync = require('child_process').execSync;

// Handle creating/removing shortcuts on Windows when installing/uninstalling.
if (require('electron-squirrel-startup')) { // eslint-disable-line global-require
  app.quit();
}

const createWindow = () => {
  // Create the browser window.
  const mainWindow = new BrowserWindow({
    width: 1780,
    height: 720,
    webPreferences: {
      contextIsolation: true,
      enableRemoteModule: false,
      preload: path.join(__dirname, "preload.js")
    },
    icon: path.join(__dirname,'../icons/captain.png')
  });

  // and load the index.html of the app.
  mainWindow.loadFile(path.join(__dirname, '../src/wrapper.html'));

  // Open the DevTools.
  // mainWindow.webContents.openDevTools();
};

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.on('ready', createWindow);

// Quit when all windows are closed, except on macOS. There, it's common
// for applications and their menu bar to stay active until the user quits
// explicitly with Cmd + Q.
app.on('window-all-closed', () => {
  if (process.platform !== 'darwin') {
    app.quit();
  }
});

app.on('activate', () => {
  // On OS X it's common to re-create a window in the app when the
  // dock icon is clicked and there are no other windows open.
  if (BrowserWindow.getAllWindows().length === 0) {
    createWindow();
  }
});

// In this file you can include the rest of your app's specific main process
// code. You can also put them in separate files and import them here.
const { ipcMain } = require('electron')
const exec = require('child_process').exec;
ipcMain.on('restartAppRoot', (event, arg) => {
  let appPath = app.getPath('exe');
  let user = os.userInfo()["username"];
  let weirdBug = fs.existsSync("/etc/redhat-release");
  let command = "/usr/bin/pkexec env DISPLAY=$DISPLAY XAUTHORITY=$XAUTHORITY /usr/bin/nohup " + appPath + " --no-sandbox --user=" + user + (weirdBug ? " &" : "");
  exec(command);
  app.quit();
})

let customUser = app.commandLine.getSwitchValue('user');
ipcMain.on('restartAppUser', (event, arg) => {
  let appPath = app.getPath('exe');
  let weirdBug = fs.existsSync("/etc/redhat-release");
  let command = "/usr/sbin/runuser -u "+ customUser +" env DISPLAY=$DISPLAY XAUTHORITY=$XAUTHORITY /usr/bin/nohup " + appPath + (weirdBug ? " &" : "");
  exec(command);
  app.quit();
});

ipcMain.on('getVersion', (event, arg) => {
  event.reply('receiveVersion',app.getVersion());
});

let policiesPath = "/usr/local/share/zabit/policies";
let policies = [];
if(fs.existsSync(policiesPath)){
  let data = fs.readFileSync(policiesPath);
  if(data){
    let foo = data.toString();
    foo.split("\n").forEach(function(row){
      if (row === ""){
        return;
      }
      let bar = row.split("=");
      policies[bar[0].trim()] = bar[1].trim();
    });
  }
}

ipcMain.on('getPolicies',(event,arg) => {
  event.reply('receivePolicies',policies);
});

ipcMain.on('quit',(event,arg) => {
  app.quit();
});

ipcMain.on('getAppPath',(event) => {
  event.reply('receiveAppPath',app.getAppPath());
});

ipcMain.on('getRealUserName',(event) => {
  event.reply('receiveRealUsername',customUser);
});