const { contextBridge,ipcRenderer } = require('electron');
const exec = require('child_process').exec;
const execSync = require('child_process').execSync;
const fs = require('fs');
const os = require('os');
const https = require('https');
const PLUGIN_PATH = "/usr/local/share/zabit/plugins";
let pluginFolders = [];
if(fs.existsSync(PLUGIN_PATH)){
    pluginFolders = fs.readdirSync(PLUGIN_PATH);
}
let pluginConfigs = {};

let policies = [];
ipcRenderer.on('receivePolicies',function(event,args){
    policies = args;
    if (safeMode === false && checkPolicy("rootmode") === "false"){
        warnPolicy();
        ipcRenderer.send('quit');
    }

    loadConfigs();
})

ipcRenderer.send('getPolicies');

function loadConfigs() {
    let pluginPolicies = checkPolicy("plugins");
    pluginFolders.forEach(function(plugin){
        if(!(plugin in pluginConfigs)){
            let path = PLUGIN_PATH + "/" + plugin + "/config.json";
            if(pluginPolicies !== true && !pluginPolicies.includes(plugin)){
                return;
            }
            if(fs.existsSync(path)) {
                pluginConfigs[plugin] = JSON.parse(fs.readFileSync(path).toString());
            }else{
                pluginConfigs[plugin] = {};
            }
        }
    });
}

contextBridge.exposeInMainWorld(
    "zabit", {
        "runCommand": (data, encoded = false) => {
            if (encoded === true) {
                data = atob(data);
            }
            try{
                return execSync(data).toString().trim()
            }catch (err){
                return err;
            }
        },
        "runLiveCommand": (data, callback,next) => {
            let pipe = exec(data, (error, stdout, stderr) => {
                callback(stdout, stderr)
            });
            pipe.stdout.on('end',() => next());
        }
    }
);

contextBridge.exposeInMainWorld(
    "plugins", {
        "getConfigs" : () => {return pluginConfigs},
        "basePath" : PLUGIN_PATH
    }
);

let intervals = {"index" : []};
let currentPlugin = "index";
let currentUser = os.userInfo()["uid"];
let safeMode = currentUser !== 0;
let username = os.userInfo()["username"];

ipcRenderer.on('receiveRealUsername',function(event,args){
    username = args;
})

if(currentUser === 0){
    ipcRenderer.send('getRealUserName');
}

function restartAppRoot(){
    if (checkPolicy("rootmode") === "false"){
        warnPolicy();
        return;
    }
    ipcRenderer.send('restartAppRoot');
}

function restartAppRegular(){
    ipcRenderer.send('restartAppUser');
}

let prettyOSName = execSync("awk -F= '$1==\"NAME\" { print $2 ;}' /etc/os-release").toString().trim().replaceAll("\"","") + " " +
    execSync("awk -F= '$1==\"VERSION\" { print $2 ;}' /etc/os-release").toString().trim().replaceAll("\"","");
let osCode = execSync("awk -F= '$1==\"ID\" { print $2 ;}' /etc/os-release").toString().trim().replaceAll("\"","");

function getPrettyOSName() {
    return prettyOSName;
}

function getOSCode() {
    return osCode;
}

let appVersion;
let appPath;
ipcRenderer.on('receiveVersion',function(event,args){
    appVersion = args;
})

ipcRenderer.send('getVersion');

ipcRenderer.on('receiveAppPath',function(event,args){
    appPath = args;
})

ipcRenderer.send('getAppPath');

contextBridge.exposeInMainWorld(
    "system", {
        "fs" : fs,
        "addInterval" : function(interval){
            intervals[currentPlugin].push(interval);
        },
        "setCurrentPlugin" : function(name){
            intervals[currentPlugin].forEach(function(interval) {
                clearInterval(interval);
            });
            intervals[currentPlugin] = [];
            intervals[name] = [];
            currentPlugin = name;
        },
        "getIntervals" : () => {return intervals},
        "getCurrentPlugin" : () => {return currentPlugin},
        "safeMode" : safeMode,
        "restartAppRoot" : restartAppRoot,
        "restartAppRegular" : restartAppRegular,
        "getPrettyOS" : getPrettyOSName,
        "getOSCode" : getOSCode,
        "getVersion" : getVersion,
        "policy" : checkPolicy,
        "appPath" : getAppPath,
        "download" : (url, dest, cb) => {
            let file = fs.createWriteStream(dest);
            https.get(url, function(response) {
                response.pipe(file);
                file.on('finish', function() {
                    file.close(cb);
                });
            });
        },
        "getUsername" : () => {return username},
        "getUserId" : () => {return currentUser}
    }
);

function getAppPath() {
    return appPath;
}

function getVersion() {
    return appVersion;
}

function checkPolicy(name){
    if(name in policies){
        return policies[name];
    }
    return true;
}

function warnPolicy(){
    alert("Bu işlemi yapmanız sistem politikası tarafından engellenmiş!");
}