let mainContainer = $("#mainContainer");

function resourceUsageCycle() {
    updateUsage();
    setInterval(() => {
        updateUsage();
    }, 1500);

    function updateUsage() {
        let cpu = parseInt(getCPUUsage());
        let ram = parseInt(getRamUsage());
        let disk = parseInt(getDiskUsage());
        $("#cpuUsage").text(cpu);
        $("#ramUsage").text(ram);
        $("#diskUsage").text(disk);
    }
}

function getHostname() {
    return zabit.runCommand("hostname");
}

function setHostname(hostname) {
    zabit.runCommand("hostnamectl set-hostname " + hostname);
    zabit.runCommand("echo '127.0.1.1	" + hostname + "' >> /etc/hosts");
    zabit.runCommand("sed -i '/127.0.1.1/d' /etc/hosts");
}

function getCPUUsage() {
    return zabit.runCommand("KGdyZXAgJ2NwdSAnIC9wcm9jL3N0YXQ7c2xlZXAgMC4xO2dyZXAgJ2NwdSAnIC9wcm9jL3N0YXQpfGF3ayAtdiBSUz0iIiAne3ByaW50ICIiKCQxMy0kMiskMTUtJDQpKjEwMC8oJDEzLSQyKyQxNS0kNCskMTYtJDUpIiJ9Jw==", true);
}

function getRamUsage() {
    return zabit.runCommand("YXdrICcvTWVtVG90YWwve3Q9JDJ9L01lbUF2YWlsYWJsZS97YT0kMn1FTkR7cHJpbnQgMTAwLTEwMCphL3QiIn0nIC9wcm9jL21lbWluZm8=", true);
}

function getDiskUsage() {
    return zabit.runCommand("ZGYgLS10eXBlIGJ0cmZzIC0tdHlwZSBleHQ0IC0tdHlwZSBleHQzIC0tdHlwZSBleHQyIC0tdHlwZSB2ZmF0IC0tdHlwZSBpc285NjYwIC0tdHlwZSBmdXNlYmxrIC1tIC0tdG90YWwgfCB0YWlsIC0xIHwgYXdrICd7cHJpbnQgJDV9Jw==",true).slice(0,-1);
}

function initializePlugins(){
    $("#osName").text(system.getPrettyOS());
    $("#zabitVersion").text(system.getVersion());
    let foo = plugins.getConfigs();
    let container = $("#navItems");
    let basePath = plugins.basePath;
    if(foo.length === 0){
        return
    }

    container.append("<li class=\"c-sidebar-nav-title\">Eklentiler</li>");
    for (const [key, value] of Object.entries(foo)) {
        container.append("<li class=\"c-sidebar-nav-item\"><a data-plugin=\"" + key + "\" class=\"c-sidebar-nav-link \" href=\""
            + basePath + "/" + key + "/index.html\">" +
            "<i class=\"" + value.icon + " c-sidebar-nav-icon\"></i>" + value.title + "</a></li>");
    }
}
let loadedScripts = ["/usr/local/share/zabit/plugins/ZABIT/loader.js"];
$(document).on("click", "a", function(e) {
    e.preventDefault();
    let current = $(this);
    let parent = current.parent();

    let url = current.attr("href");
    if(url.startsWith("#")){
        return
    }

    mainContainer.load(url,null,function(){
        if(current.attr("data-plugin") !== false){
            let plugin = current.attr("data-plugin");
            if (plugin === undefined){
                return;
            }
            if (plugin !== "ZABIT"){
                system.setCurrentPlugin(plugin);
            } else{
                window[parent.attr("data-onload")]();
            }

            let scriptUrl = plugins.basePath + "/" + plugin + "/loader.js";
            let initFunc = plugin + "Init";
            let fileExists = system.fs.existsSync(scriptUrl);
            if(loadedScripts.includes(scriptUrl) === false && fileExists){
                window.plugin = {};
                $.getScript(scriptUrl,function(){
                    window[initFunc]();
                });
                loadedScripts.push(scriptUrl);
            }else if(typeof window[plugin + "Init"] !== "undefined"){
                window[initFunc]();
            }
        }
    });
    if(parent.hasClass("c-sidebar-nav-item")) {
        $(".c-active").each(function(){
            $(this).removeClass("c-active");
        })
        current.addClass("c-active");
    }
});

orj = setInterval;
setInterval = function(handler, timeout, ...arguments) {
    return system.addInterval(orj(handler,timeout,arguments));
}

initializePlugins();

function indexLoad(){
    system.setCurrentPlugin("index");
    mainContainer.load('index.html',null,function(){
        resourceUsageCycle();
        showDiskDetails(false);
        showCpuDetails(false);
        showRamDetails(false);
        showOsDetails(false);
        let url = system.policy('rssUrl');
        if(url=== true || url === ""){
            url = "https://www.pardus.org.tr/sss";
        }
        $("#rssFeed").attr("src",url);
    });
}

function servicesLoad(){
    system.setCurrentPlugin("services");
    getSystemServices();
}

let servicesTable;
function getSystemServices(){
    let command = "systemctl list-units -t service --full --all --plain --no-legend | awk '{$2=\"\";$3=\"\";$1=$1\",\";$4=$4\",\"; print}'";
    let rawServices = zabit.runCommand(command);
    let services = [];
    let stopCount = 0;
    let activeCount = 0;
    rawServices.split("\n").forEach(function(row){
        let foo = row.split(",");
        let status = foo[1].trim();
        if (status === "running") {
            status = "Çalışıyor";
            activeCount++;
        }else{
            status = "Pasif";
            stopCount++;
        }
        services.push({
            "service" : foo[0].trim().slice(0,-8),
            "status" : status,
            "description" : foo[0].trim() === foo[2].trim() ? "" : foo[2].trim()
        });

    });

    servicesTable = $("#services").DataTable({
        "pageLength" : 50,
        "lengthChange" : false,
    });
    services.forEach(function(service){
        servicesTable.row.add( [
            service["service"],
            service["description"],
            service["status"]
        ] );
    });
    servicesTable.draw();

    $("#activeServiceCount").text(activeCount);
    $("#stoppedServiceCount").text(stopCount);
    $("#allServiceCount").text(activeCount+ stopCount);
}

function stopSystemService(name){
    swal( {
        text: name.slice(0,-8) + " servisini durdurmak istediğinize emin misiniz?",
        icon: "warning",
        title: "Servisi Durdur",
        dangerMode: true,
        buttons: {
            cancel: "İptal",
            stop: {
                text: "Servisi Durdur",
            },
        },
    })
        .then((value) => {
            switch (value) {
                case "stop":
                    swal("Gotcha!", "Pikachu was caught!", "success");
                    break;
            }
        });
}

function startSystemService(name){
    swal( {
        text: name.slice(0,-8) + " servisini başlatmak istediğinize emin misiniz?",
        icon: "warning",
        title: "Servisi Başlat",
        dangerMode: true,
        buttons: {
            cancel: "İptal",
            stop: {
                text: "Servisi Başlat",
            },
        },
    })
        .then((value) => {
            switch (value) {
                case "stop":
                    swal("Gotcha!", "Pikachu was caught!", "success");
                    break;
            }
        });
}

function showSwal(message, type, timer = false) {
    var config = {
        position: "bottom-start",
        icon: type,
        title: message,
        toast: true,
        button: false,
    };
    if (timer) {
        config["timer"] = timer;
    }
    swal(config);
}

function setSafeState(){
    let activeSafeMode = $("#activeSafeMode");
    let activeRootMode = $("#activeRootMode");

    if(!system.safeMode){
        activeSafeMode.fadeIn(0);
        activeRootMode.fadeOut(0);
    }else{
        activeRootMode.fadeIn(0);
        activeSafeMode.fadeOut(0);
    }
}

function changeRootState(){
    if(!system.safeMode){
        activeSafeMode.fadeIn(0);
        activeRootMode.fadeOut(0);
    }else{
        activeRootMode.fadeIn(0);
        activeSafeMode.fadeOut(0);
    }
}

function showOsDetails(showModal = true){
    let osRelease = zabit.runCommand("cat /etc/os-release");
    let modal = $("#osDetailsModal");
    let list = modal.find("#osDetailsList");
    let list2 = $("#osDetailsListIndex");
    let str = "";
    let known = {
        "NAME" : "İsim",
        "VERSION" : "Versiyon",
        "ID" : "Kod",
        "ID_LIKE" : "Türü",
        "PRETTY_NAME" : "Alternatif İsim",
        "VERSION_CODENAME" : "Kod Adı",
        "HOME_URL" : "Ana Sayfa",
        "SUPPORT_URL" : "Destek Sayfası"
    };
    osRelease.split("\n").forEach(function(row){
        let parsed = row.replaceAll("\"","").split("=");
        if (parsed[0] in known){
            str += "<li class=\"list-group-item\">" + known[parsed[0]] +"<span class='float-right'>" + parsed[1] +"</span></li>";
        }
    });
    list.html(str);
    list2.html(str);
    if(showModal){
        new coreui.Modal(document.getElementById('osDetailsModal'), {
            keyboard: false
        }).show();
    }
}

function showCpuDetails(showModal = true){
    let genericInfomation = zabit.runCommand("LANG=en_US /usr/bin/lscpu").split("\n");
    let modal = $("#cpuDetailsModal");
    let list = modal.find("#cpuDetailsList");
    let list2 = $("#cpuDetailsListIndex");
    let str = "";
    let known = {
        "Model name" : "İşlemci Adı",
        "CPU(s)" : "Çekirdek Sayısı",
        "CPU max MHz" : "Maksimum Hız",
        "CPU min MHz" : "Minimum Hız",
        "Virtualization" : "Sanallaştırma",
        "Architecture" : "Mimari"
    };
    let parsedData = [];
    genericInfomation.forEach(function(row){
        let parsed = row.split(":");
        let key = parsed[0].trim();
        let value = parsed[1].trim();
        if (key in known){
            parsedData[key] = value;
            if(key === "CPU max MHz" || key === "CPU min MHz") {
                value = (parseInt(value.split(".")[0]) / 1000).toFixed(2).toString() + " GHz";
            }
            str += "<li class=\"list-group-item\">" + known[key] +"<span class='float-right'>" + value +"</span></li>";
        }
    });
    list.html(str);
    list2.html(str);
    let coreCount = parsedData["CPU(s)"];
    let ctx = document.getElementById('cpuDetailsCanvas');
    let ctx2 = document.getElementById('cpuDetailsCanvasIndex');
    let cpuMhzChart;
    let cpuMhzChart2;
    if(showModal){
        cpuMhzChart = new Chart(ctx, {
            type: 'bar',
            data: {
                labels: Array.apply(null, {length: coreCount}).map(Number.call, Number),
                datasets: [{
                    label: 'Çekirdek Bazlı Anlık Hızlar',
                    data: [],
                    borderWidth: 1
                }]
            },
            options: {
                scales: {
                    y: {
                        min: parseInt(parsedData["CPU min MHz"]),
                        max: parseInt(parsedData["CPU max MHz"]),
                    }
                },
                tooltips: {
                    enabled: false
                }
            }
        });
    }else{
        cpuMhzChart2 = new Chart(ctx2, {
            type: 'bar',
            data: {
                labels: Array.apply(null, {length: coreCount}).map(Number.call, Number),
                datasets: [{
                    label: 'Çekirdek Bazlı Anlık Hızlar',
                    data: [],
                    borderWidth: 1
                }]
            },
            options: {
                scales: {
                    y: {
                        min: parseInt(parsedData["CPU min MHz"]),
                        max: parseInt(parsedData["CPU max MHz"]),
                    }
                },
                tooltips: {
                    enabled: false
                }
            }
        });
    }



    function getCpuMHZ(){
        let res = zabit.runCommand("cat /proc/cpuinfo | grep \"cpu MHz\"");
        function loopData(data){
            data.datasets.forEach(dataset => {
                let data = [];
                res.split("\n").forEach(function(row){
                    let foo = row.split(":")[1].trim();
                    data.push(parseInt(foo));
                });
                dataset.data = data;
            });
        }
        if(showModal){
            loopData(cpuMhzChart.data);
            cpuMhzChart.update();
        }else{
            loopData(cpuMhzChart2.data);
            cpuMhzChart2.update();
        }
    }
    getCpuMHZ();

    if(showModal){
        let intervalObj = orj(getCpuMHZ,1500);
        new coreui.Modal(document.getElementById('cpuDetailsModal'), {
            keyboard: false
        }).show();
        document.getElementById('cpuDetailsModal').addEventListener('hidden.coreui.modal', function (e) {
            clearInterval(intervalObj);
        });
    }else{
        setInterval(getCpuMHZ,1500);
    }

}

function showRamDetails(showModal = true){
    let command = "free -m  | tail -n +2 | tr -s ' ' | cut -d ' ' -f 1,2,3";
    let ctx = document.getElementById('ramDetailsCanvas');
    let ctx2 = document.getElementById('ramDetailsCanvasIndex');
    let totalRam = parseInt(zabit.runCommand("echo $(($(getconf _PHYS_PAGES) * $(getconf PAGE_SIZE) / (1024 * 1024)))"));
    $("#totalAvailableRam").text(totalRam + " MB");
    $("#totalAvailableRamIndex").text(totalRam + " MB");
    let ramMhzChart;
    let ramMhzChart2;
    if(showModal){
        ramMhzChart = new Chart(ctx, {
            type: 'horizontalBar',
            data: {
                labels: ['Ram', 'Swap'],
                datasets: [{
                    label: 'Aktif Ram Kullanımı (mb)',
                    data: [],
                    borderWidth: 1
                }]
            },
            options: {
                indexAxis: 'y',
                tooltips: {
                    enabled: false
                },
                scales: {
                    xAxes : [{
                        ticks : {
                            max : totalRam ? totalRam : 32000,
                            min : 0
                        }
                    }]
                }
            }
        });
    }else{
        ramMhzChart2 = new Chart(ctx2, {
            type: 'horizontalBar',
            data: {
                labels: ['Ram', 'Swap'],
                datasets: [{
                    label: 'Aktif Ram Kullanımı (mb)',
                    data: [],
                    borderWidth: 1
                }]
            },
            options: {
                indexAxis: 'y',
                tooltips: {
                    enabled: false
                },
                scales: {
                    xAxes : [{
                        ticks : {
                            max : totalRam ? totalRam : 32000,
                            min : 0
                        }
                    }]
                }
            }
        });
    }



    let totalUsageRam = $("#totalUsageRam");
    let totalUsageRam2 = $("#totalUsageRamIndex");

    function getRamUsage(){
        let res = zabit.runCommand(command);
        function loopThrough(data){
        data.data.datasets.forEach(dataset => {
                let data = [];
                res.split("\n").forEach(function(row){
                    let foo = row.split(" ");
                    let currentRam = foo[2].trim();
                    if(foo[0] === "Mem:") {
                        totalUsageRam.text(currentRam + " MB");
                        totalUsageRam2.text(currentRam + " MB");
                    }
                    data.push(currentRam);
                });
                dataset.data = data;
            });
        }
        if(showModal){
            loopThrough(ramMhzChart);
            ramMhzChart.update();
        }else{
            loopThrough(ramMhzChart2);
            ramMhzChart2.update();
        }
    }
    getRamUsage();
    if(showModal){
        let intervalObj = orj(getRamUsage,1500);
        new coreui.Modal(document.getElementById('ramDetailsModal'), {
            keyboard: false
        }).show();document.getElementById('ramDetailsModal').addEventListener('hidden.coreui.modal', function (e) {
            clearInterval(intervalObj);
        });
    }else{
        setInterval(getRamUsage,1500);
    }
}

function showDiskDetails(showModal = true){
    let command = "df --type btrfs --type ext4 --type ext3 --type ext2 --type vfat --type iso9660 --type fuseblk -m | tail -n +2 | awk '{print $1,$2,$3,$5,$6}'";
    let ctx = document.getElementById('diskDetailsCanvas');
    let ctx2 = document.getElementById('diskDetailsCanvasIndex');
    let initialData = zabit.runCommand(command);
    let diskNames = [];
    initialData.split("\n").forEach(function (row){
        diskNames.push(row.split(" ")[0]);
    });
    let disksChart = new Chart(ctx, {
        type: 'horizontalBar',
        data: {
            labels: diskNames,
            datasets: [{
                label: 'Disk Doluluk Oranları',
                data: [],
                borderWidth: 1
            }]
        },
        options: {
            indexAxis: 'y',
            tooltips: {
                enabled: false
            },
            scales: {
                xAxes : [{
                    ticks : {
                        max : 100,
                        min : 0
                    }
                }]
            }
        }
    });
    let disksChart2 = new Chart(ctx2, {
        type: 'horizontalBar',
        data: {
            labels: diskNames,
            datasets: [{
                label: 'Disk Doluluk Oranları',
                data: [],
                borderWidth: 1
            }]
        },
        options: {
            indexAxis: 'y',
            tooltips: {
                enabled: false
            },
            scales: {
                xAxes : [{
                    ticks : {
                        max : 100,
                        min : 0
                    }
                }]
            }
        }
    });
    getDiskUsage();
    function getDiskUsage(){
        let res = zabit.runCommand(command);
        function loopThrough(data){
            data.data.datasets.forEach(dataset => {
                let data = [];
                res.split("\n").forEach(function(row){
                    data.push(parseInt(row.split(" ")[3].slice(0,-1)));
                });
                dataset.data = data;
            });
        }
        loopThrough(disksChart);
        loopThrough(disksChart2);
        disksChart2.update();
    }
    if(showModal){
        let intervalObj = orj(getRamUsage,10000);
        new coreui.Modal(document.getElementById('diskDetailsModal'), {
            keyboard: false
        }).show();
        document.getElementById('diskDetailsModal').addEventListener('hidden.coreui.modal', function (e) {
            clearInterval(intervalObj);
        });
    }else{
        setInterval(getDiskUsage,10000);
    }

}

setSafeState();
indexLoad();

let updates = [];
let apt = ["ubuntu", "pardus", "debian"];
let rpm = ["fedora"];
let os = system.getOSCode();
let updatesTable;
let packageType = "deb";
updates = [];
if(apt.includes(os)){
    packageType = "deb";
}
if(rpm.includes(os)){
    packageType = "rpm";
}
function setUpdates(){
    updates = [];
    if (packageType === "deb"){
        checkAptUpdates();
    }
    if (packageType === "rpm"){
        checkRpmUpdates();
    }
    if(updatesTable) {
        updatesTable.clear().destroy();
    }

    updatesTable = $("#updates").DataTable({
        "pageLength" : 50,
        "lengthChange" : false
    });
    updates.forEach(function(update){
        updatesTable.row.add( [
            update.name,
            update.version,
        ] );
    });
    updatesTable.draw();
    $("#updatesCount").text(updates.length);
}

function checkAptUpdates(){
    let command = "LANG=en_US apt-get --just-print upgrade | grep Inst | awk '{print $2,$3}'";
    let resp = zabit.runCommand(command);
    if (resp === ""){
        return;
    }
    resp.split("\n").forEach(function(row){
        let parsed = row.split(" ");
        let version = parsed[1].trim();
        updates.push({
           "name" : parsed[0].trim(),
           "version" :  version.substr(1,version.length -2)
        });
    });
}

function checkRpmUpdates(){
    let command = "dnf list --upgrades | tail -n +3 | awk '{print $1,$2}'";
    let resp = zabit.runCommand(command);
    if (resp === ""){
        return;
    }
    resp.split("\n").forEach(function(row){
        let parsed = row.split(" ");
        updates.push({
            "name" : parsed[0].trim(),
            "version" :  parsed[1].trim()
        });
    });
}

function restartAsRoot(){
    swal( {
        text: "Güvenli modu kapatmak istediğinize emin misiniz?",
        icon: "warning",
        dangerMode: true,
        buttons: {
            cancel: "İptal",
            stop: {
                text: "Devam",
            },
        },
    })
        .then((value) => {
            switch (value) {
                case "stop":
                    system.restartAppRoot();
                    break;
            }
        });
}

function restartAsUser(){
    swal( {
        text: "Yetkili modu kapatmak istediğinize emin misiniz?",
        icon: "warning",
        dangerMode: true,
        buttons: {
            cancel: "İptal",
            stop: {
                text: "Devam",
            },
        },
    })
        .then((value) => {
            switch (value) {
                case "stop":
                    system.restartAppRegular()
                    break;
            }
        });
}

function updatesLoad(){
    setUpdates();
}

let packages = [];
function packagesLoad(force = false){
    if (packages.length > 0 && force === false) {
        drawAppsTable();
        return;
    }
    let command = "dpkg -l | grep ^ii | awk '{$1=\"\";$4=\"\";$2=$2\",\";$3=$3\",\"; print}'";
    if (packageType === "rpm") {
        command = "dnf list installed | awk '{$1=$1\",\";$2=$2\",\";print $1,$2}'";
    }
    let output = zabit.runCommand(command);
    output.split("\n").forEach(function(row){
        let foo = row.split(",");
        packages.push({
            "name" : foo[0].trim(),
            "version": foo[1].trim(),
            "description": foo[2].trim()
        });
    });
    drawAppsTable();
}

let packagesTable = null;
function drawAppsTable(){
    if(packagesTable !== null){
        packagesTable.clear().destroy();
    }
    packagesTable = $("#packages").DataTable({
        "pageLength": 50,
        "lengthChange": false,
    });

    packages.forEach(function(service){
        packagesTable.row.add( [
            service["name"],
            service["description"],
            service["version"]
        ] );
    });
    packagesTable.draw();
    $("#installedAppsCount").text(packages.length);
    let foo = 0;
    $('#fileUpload').on(
        'dragover',
        function(e) {
            e.preventDefault();
            e.stopPropagation();
        }
    ).on(
        'dragleave',
        function(e) {
            foo--;
            if(foo === 0){
                $("#packageInstallCard").removeClass('dragEffect');
            }

            e.preventDefault();
            e.stopPropagation();
        }
    ).on(
        'dragenter',
        function(e) {
            $("#packageInstallCard").addClass('dragEffect');
            foo++;
            e.preventDefault();
            e.stopPropagation();
        }
    ).on(
        'drop',
        function(e){
            if(e.originalEvent.dataTransfer.files.length) {
                e.preventDefault();
                e.stopPropagation();
                $("#packageInstallCard").removeClass('dragEffect');
                showFileInstallPopup(e.originalEvent.dataTransfer.files);
            }
        }
    );
}

let toInstall = [];
let activeInstall = false;
function showFileInstallPopup(files){
    if(system.safeMode) {
        swal("Yetki Hatası", "Bu işlemi güvenli modda yapamazsınız!", "error", {
            button: "Tamam",
        });
        return;
    }
    let list = $("#packageInstallList");
    list.text("");
    for(let i = 0 ; i < files.length; i++){
        if(files[i].name.substr(-3) !== packageType) {
            swal("Bu paket kurulamaz!", files[i].name + " paketi bu işletim sisteminde kurulamıyor.", "error", {
                button: "Tamam",
            });
            return;
        }
        toInstall.push(files[i].path);
        list.append(files[i].name + "\n");
    }
    upgradeMode = false;
    $("#packageInstallModal .modal-title").text("Paket Kurulumu");
    $("#packageInstallButton").text("Paketleri Kur");
    new coreui.Modal(document.getElementById('packageInstallModal'), {
        keyboard: false
    }).show();
}
let upgradeMode = false;
function installPackages(){
    let button = $("#packageInstallButton");
    button.attr("disabled",true);
    let logs = $("#packageInstallOutput");
    if(activeInstall){
        return;
    }
    logs.text("");
    let command = "DEBIAN_FRONTEND=noninteractive apt install -yq ";
    if (packageType === "rpm"){
        if(upgradeMode){
            command = "dnf upgrade -y ";
        }else{
            command = "dnf install -y ";
        }
    }
    toInstall.forEach(function(row){
       command += row + " ";
    });
    zabit.runLiveCommand(command,function(stdout,stderr){
        logs.append(stdout + stderr);
    },function(){
        button.attr("disabled",false);
        swal({
            text: "İşlem tamamlandı!",
            timer: 2000
        });
    });
}

function selectPackagesToInstall(){
    if(system.safeMode) {
        swal("Yetki Hatası", "Bu işlemi güvenli modda yapamazsınız!", "error", {
            button: "Tamam",
        });
        return;
    }
    var input = document.createElement('input');
    input.type = 'file';
    input.multiple = true;
    input.click();
    input.addEventListener('change',() => {showFileInstallPopup(input.files)});
}

$(document.body).on('click', '#packages tbody tr', function () {
    let data = packagesTable.row( this ).data();
    if(packageType === "deb"){
        let command = "dpkg-query -W -f='${Package}***${Version}***${Description}***${Depends}***${Homepage}\\n' " + data[0];
        let output = zabit.runCommand(command);
        let details = output.split("***");
        let list = $("#packageDetailsDependencies");
        let str = "";
        $("#packageDetailsName").text(details[0]);
        $("#packageDetailsVersion").text(details[1]);
        $("#packageDetailsDescription").text(details[2]);
        details[3].split(",").forEach(function(dependency){
            str += "<li class=\"list-group-item\">" + dependency +"</li>";
        });
        list.html(str);
        $("#packageDetailsHomepage").html(details[4]);
    }else{
        let command = "rpm -q --queryformat '%{DESCRIPTION}*%{URL}\\n' " + data[0];
        let output = zabit.runCommand(command);
        let depends = "rpm -q --requires " + data[0];
        let dependsOutput = zabit.runCommand(depends);
        let parsed = output.split("*");
        $("#packageDetailsName").text(data[0]);
        $("#packageDetailsVersion").text(data[2]);
        $("#packageDetailsDescription").text(parsed[0]);
        $("#packageDetailsHomepage").html(parsed[1]);
        let list = $("#packageDetailsDependencies");
        let str = "";
        dependsOutput.split("\n").forEach(function(dependency){
            str += "<li class=\"list-group-item\">" + dependency +"</li>";
        });
        list.html(str);
    }

    new coreui.Modal(document.getElementById('packageDetailsModal'), {
        keyboard: false
    }).show();
} );

$(document.body).on('click', '#services tbody tr', function () {
    let data = servicesTable.row( this ).data();
    let command = "systemctl show "+ data[0] +" | grep 'Description=\\|WantedBy=\\|Requires=\\|Before=\\|After=\\|ActiveState='";
    let output = zabit.runCommand(command);
    let logs;
    if ((system.getOSCode() === "pardus" || system.getOSCode() === "debian") && system.safeMode) {
        logs = "Logları bu işletim sisteminde güvenli modda göremezsiniz!";
    }else{
        logs = zabit.runCommand("journalctl --unit=" + data[0] + " -n 100 --no-pager");
    }
    let parsed = {
        "Description" : "",
        "WantedBy" : "",
        "Requires" : "",
        "Before" : "",
        "After" : "",
        "ActiveState" : ""
    };
    output.split("\n").forEach(function (row){
        let foo = row.split("=");
        parsed[foo[0].trim()] = foo[1].trim();
    });

    $("#serviceDetailsName").text(data[0]);
    $("#serviceDetailsDescription").text(parsed["Description"]);
    let list = $("#serviceDetailsDependencies");
    let str = "";
    parsed["Requires"].split(" ").forEach(function(dependency){
        str += "<li class=\"list-group-item\">" + dependency +"</li>";
    });
    list.html(str);

    list = $("#serviceDetailsBefore");
    str = "";
    parsed["Before"].split(" ").forEach(function(dependency){
        str += "<li class=\"list-group-item\">" + dependency +"</li>";
    });
    list.html(str);

    list = $("#serviceDetailsAfter");
    str = "";
    parsed["After"].split(" ").forEach(function(dependency){
        str += "<li class=\"list-group-item\">" + dependency +"</li>";
    });
    list.html(str);

    let logsArea = $("#serviceLogs");
    logsArea.text(logs).scrollTop(logsArea.height);
    new coreui.Modal(document.getElementById('serviceDetailsModal'), {
        keyboard: false
    }).show();
} );

$(document.body).on('click', '#updates tbody tr', function () {
    let asd = $(this);
    asd.toggleClass('selectedUpdate');
    asd.removeClass('odd');
} );

function installSelectedUpdates(){
    if(system.safeMode) {
        swal("Yetki Hatası", "Bu işlemi güvenli modda yapamazsınız!", "error", {
            button: "Tamam",
        });
        return;
    }

    toInstall = [];
    let foo = updatesTable.rows('.selectedUpdate').data();
    let list = $("#packageInstallList");
    list.text("");
    for(let i =0 ; i < foo.length; i++){
        toInstall.push(foo[i][0]);
        list.append(foo[i][0] + "\n");
    }

    if(toInstall.length === 0) {
        swal("Seçim Yok", "Lütfen önce güncellenecek paketleri seçin.", "error", {
            button: "Tamam",
        });
        return;
    }
    upgradeMode = true;
    $("#packageInstallModal .modal-title").text("Paket Güncellemesi");
    $("#packageInstallButton").text("Paketleri Güncelle");
    new coreui.Modal(document.getElementById('packageInstallModal'), {
        keyboard: false
    }).show();
}

function remoteLoad(){
    let sshInstalled = checkPackageInstalled("openssh-server");
    if(sshInstalled){
        $("#sshYes").fadeIn();
        loadSSHConfig();
    }else{
        $("#sshNo").fadeIn();
    }

    let vncInstalled = checkPackageInstalled("x11vnc");
    if(vncInstalled){
        $("#vncYes").fadeIn();
    }else{
        $("#vncNo").fadeIn();
    }
}

function checkPackageInstalled(packageName){
    let command;
    if(packageType === "deb"){
        command = "dpkg -s "+packageName+" 2>/dev/null 1>/dev/null && echo 1 || echo 0";
    }else{
        command = "yum list installed "+ packageName +" 2>/dev/null >/dev/null && echo 1 || echo 0"
    }
    let output = zabit.runCommand(command);
    return output === "1";
}

function setupPages(){
    let policy = system.policy("pages");
    if(policy === true || policy === "") {
        return;
    }
    $("[data-policy-links]").each(function(){
        if(!policy.includes($(this).attr('data-policy-links'))){
            $(this).fadeOut(0);
        }
    })
}

function installPackagesArray(names){
    if(system.safeMode) {
        swal("Yetki Hatası", "Bu işlemi güvenli modda yapamazsınız!", "error", {
            button: "Tamam",
        });
        return;
    }

    toInstall = names;

    let list = $("#packageInstallList");
    list.text("");
    for(let i =0 ; i < names.length; i++){
        list.append(names[i] + "\n");
    }

    upgradeMode = false;
    $("#packageInstallModal .modal-title").text("Paket Kurulumu");
    $("#packageInstallButton").text("Paketleri Kur");
    new coreui.Modal(document.getElementById('packageInstallModal'), {
        keyboard: false
    }).show();
}
setupPages();
function loadSSHConfig(){
    let command = "cat /etc/ssh/sshd_config | grep -v \"#\" | sed '/^$/d'";
    let output = zabit.runCommand(command);
    let parsed = [];
    output.split("\n").forEach(function(row){
        row = row.trim();
        row = row.replaceAll("\t"," ");
        let foo = row.split(" ");
        parsed[foo[0].trim()] = row.substr(foo[0].length).trim();
    });
    if("Subsystem" in parsed && parsed["Subsystem"] === "sftp /usr/lib/openssh/sftp-server"){
        $("#SFTPEnable").prop("checked",true);
    }
    if("X11Forwarding" in parsed && parsed["X11Forwarding"] === "yes"){
        $("#X11Forwarding").prop("checked",true);
    }

    if("PermitRootLogin" in parsed && parsed["PermitRootLogin"] === "no"){
        $("#PermitRootLogin").prop("checked",true);
    }

    if("AllowUsers" in parsed){
        $("#AllowUsers").val(parsed["AllowUsers"]);
    }

    if("DenyUsers" in parsed){
        $("#DenyUsers").val(parsed["DenyUsers"]);
    }

    if("Port" in parsed){
        $("#sshPort").val(parseInt(parsed["Port"]));
    }
}

function saveSSHConfig(){
    if(system.safeMode) {
        swal("Yetki Hatası", "Bu işlemi güvenli modda yapamazsınız!", "error", {
            button: "Tamam",
        });
        return;
    }

    function updateRow(search,newData){
        zabit.runCommand("sed -i '/"+search+"/d' /etc/ssh/sshd_config");
        if(newData !== ""){
            zabit.runCommand("echo '"+ search +"="+ newData +"' >> /etc/ssh/sshd_config");
        }
    }

    updateRow("PermitRootLogin=",($("#PermitRootLogin").is(":checked") ? "no" : "yes"));
    updateRow("X11Forwarding=",($("#X11Forwarding").is(":checked") ? "yes" : "no"));
    updateRow("AllowUsers=",$("#AllowUsers").val());
    updateRow("DenyUsers=",$("#DenyUsers").val());
    updateRow("Port=",$("#sshPort").val());
    updateRow("Subsystem",($("#SFTPEnable").is(":checked") ? "Subsystem       sftp    /usr/lib/openssh/sftp-server" : ""));

    swal("İşlem Başarılı!", "Dosya düzenlendi, değişikliklerin aktif olması için servisi yeniden başlatmayı unutmayın.", "success", {
        button: "Tamam",
    });
}

function restartSSHD(){
    if(system.safeMode) {
        swal("Yetki Hatası", "Bu işlemi güvenli modda yapamazsınız!", "error", {
            button: "Tamam",
        });
        return;
    }
    zabit.runCommand("systemctl restart sshd");

    swal("İşlem Başarılı!", "Servis yeniden başlatıldı.", "success", {
        button: "Tamam",
    });
}

let vncConfig = [];
function startVnc() {
    if(system.safeMode) {
        swal("Yetki Hatası", "Bu işlemi güvenli modda yapamazsınız!", "error", {
            button: "Tamam",
        });
        return;
    }

    let port = $("#vncPort").val();
    if(parseInt(port) < 1024) {
        swal("Tehlikeli Port", "Bu portu 1023'den büyük seçmelisiniz, aksi taktirde vnc root kullanıcısı olarak açıklacaktır ki bu da önerilmemektedir.", "error", {
            button: "Tamam",
        });
        return;
    }

    console.log(zabit.runCommand("killall x11vnc"));
    vncConfig["port"] = port;
    let viewOnly = $("#vncViewOnly").is(':checked');
    vncConfig["viewOnly"] = viewOnly;
    let password = $("#vncPassword").val();
    command = "x11vnc -forever -rfbport " + port + (viewOnly ? " -viewonly" : "") + (password !== "" ? " -passwd " + password : " -nopw");
    zabit.runLiveCommand(command,function(){},function(){});

    swal("İşlem Başarılı!", "x11vnc başlatıldı!", "success", {
        button: "Tamam",
    });
}

